pub struct UniqueResult<T>where
T: Element,{
pub values: Array<T, Ix1>,
pub indices: Option<Array<u64, Ix1>>,
pub counts: Option<Array<u64, Ix1>>,
}Expand description
Result from the unique function.
Fields
values: Array<T, Ix1>The sorted unique values.
indices: Option<Array<u64, Ix1>>If requested, the indices of the first occurrence of each unique value in the original array (as u64).
counts: Option<Array<u64, Ix1>>If requested, the count of each unique value (as u64).