pub fn select<T, D>(
condlist: &[Array<bool, D>],
choicelist: &[Array<T, D>],
default: T,
) -> Result<Array<T, IxDyn>, FerrayError>Expand description
Return an array drawn from elements in choicelist, depending on conditions.
Equivalent to np.select(condlist, choicelist, default).
The first condition that is true determines which choice is used.
Errors
InvalidValueif condlist and choicelist have different lengthsShapeMismatchif shapes are incompatible