pub trait Element:
Clone
+ Debug
+ Display
+ Send
+ Sync
+ PartialEq
+ 'static
+ Sealed {
// Required methods
fn dtype() -> DType;
fn zero() -> Self;
fn one() -> Self;
}Expand description
Trait bound for types that can be stored in a ferray array.
This is implemented for all supported numeric types plus bool.
The trait is sealed: downstream crates cannot implement it for new types
(use DynArray or FerrayRecord for custom element types).
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.